@@ -980,7 +980,8 @@ class ShanGeTu():
                 py.draw.line(backgroud,[0,0,0],[i*(self.cell_size+self.line_size),0],[i*(self.cell_size+self.line_size),pic_size])
                 py.draw.line(backgroud,[0,0,0],[0,i*(self.cell_size+self.line_size)],[pic_size,i*(self.cell_size+self.line_size)])
             return backgroud
-        elif size == 30:
+        #elif size == 30:
+        else:
             self.cell_size = 15
             self.line_size = 1
             pic_size = size*self.cell_size+(size+1)*self.line_size
